==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/statemachine/impl/LocalEventSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.statemachine.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.statemachine.CreationTransitionSet;
import io.ciera.tool.sql.ooaofooa.statemachine.LocalEvent;
import io.ciera.tool.sql.ooaofooa.statemachine.LocalEventSet;
import io.ciera.tool.sql.ooaofooa.statemachine.SEMEventSet;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.CreationTransitionSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.SEMEventSetImpl;

import java.util.Arrays;
import java.util.List;


public class LocalEventSetImpl extends InstanceSet<LocalEventSet,LocalEvent> implements LocalEventSet {

    // attributes
    @Override
    public void setSMspd_IDdeprecated( UniqueId m_SMspd_IDdeprecated ) throws XtumlException {
        for ( LocalEvent localevent : this ) localevent.setSMspd_IDdeprecated( m_SMspd_IDdeprecated );
    }
    @Override
    public void setSM_ID( UniqueId ref_SM_ID ) throws XtumlException {
        for ( LocalEvent localevent : this ) localevent.setSM_ID( ref_SM_ID );
    }
    @Override
    public void setSMevt_ID( UniqueId ref_SMevt_ID ) throws XtumlException {
        for ( LocalEvent localevent : this ) localevent.setSMevt_ID( ref_SMevt_ID );
    }


    // selections
    @Override
    public CreationTransitionSet R509_has_assigned_to_it_CreationTransition() throws XtumlException {
        CreationTransitionSet creationtransitionset = new CreationTransitionSetImpl();
        for ( LocalEvent localevent : this ) creationtransitionset.add( localevent.R509_has_assigned_to_it_CreationTransition() );
        return creationtransitionset;
    }
    @Override
    public SEMEventSet R526_is_a_SEMEvent() throws XtumlException {
        SEMEventSet semeventset = new SEMEventSetImpl();
        for ( LocalEvent localevent : this ) semeventset.add( localevent.R526_is_a_SEMEvent() );
        return semeventset;
    }


    @Override
    public LocalEvent nullElement() {
        return LocalEventImpl.EMPTY_LOCALEVENT;
    }

    @Override
    public LocalEventSet emptySet() {
      return new LocalEventSetImpl();
    }

    @Override
    public LocalEventSet value() {
        return this;
    }

    @Override
    public List<LocalEvent> elements() {
        return Arrays.asList(toArray(new LocalEvent[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/statemachine/impl/LocalEventSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.statemachine.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.statemachine.CreationTransitionSet;
import io.ciera.tool.sql.ooaofooa.statemachine.LocalEvent;
import io.ciera.tool.sql.ooaofooa.statemachine.LocalEventSet;
import io.ciera.tool.sql.ooaofooa.statemachine.SEMEventSet;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.CreationTransitionSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.SEMEventSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class LocalEventSetImpl extends InstanceSet<LocalEventSet,LocalEvent> implements LocalEventSet {

    public LocalEventSetImpl() {
    }

    public LocalEventSetImpl(Comparator<? super LocalEvent> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setSMspd_IDdeprecated( UniqueId m_SMspd_IDdeprecated ) throws XtumlException {
        for ( LocalEvent localevent : this ) localevent.setSMspd_IDdeprecated( m_SMspd_IDdeprecated );
    }
    @Override
    public void setSM_ID( UniqueId ref_SM_ID ) throws XtumlException {
        for ( LocalEvent localevent : this ) localevent.setSM_ID( ref_SM_ID );
    }
    @Override
    public void setSMevt_ID( UniqueId ref_SMevt_ID ) throws XtumlException {
        for ( LocalEvent localevent : this ) localevent.setSMevt_ID( ref_SMevt_ID );
    }


    // selections
    @Override
    public CreationTransitionSet R509_has_assigned_to_it_CreationTransition() throws XtumlException {
        CreationTransitionSet creationtransitionset = new CreationTransitionSetImpl();
        for ( LocalEvent localevent : this ) creationtransitionset.add( localevent.R509_has_assigned_to_it_CreationTransition() );
        return creationtransitionset;
    }
    @Override
    public SEMEventSet R526_is_a_SEMEvent() throws XtumlException {
        SEMEventSet semeventset = new SEMEventSetImpl();
        for ( LocalEvent localevent : this ) semeventset.add( localevent.R526_is_a_SEMEvent() );
        return semeventset;
    }


    @Override
    public LocalEvent nullElement() {
        return LocalEventImpl.EMPTY_LOCALEVENT;
    }

    @Override
    public LocalEventSet emptySet() {
      return new LocalEventSetImpl();
    }

    @Override
    public LocalEventSet emptySet(Comparator<? super LocalEvent> comp) {
      return new LocalEventSetImpl(comp);
    }

    @Override
    public LocalEventSet value() {
        return this;
    }

    @Override
    public List<LocalEvent> elements() {
        return Arrays.asList(toArray(new LocalEvent[0]));
    }

}
